@@ -10,7 +10,7 @@ api_key = None
 private_secret = None
 api_base = "https://api.transfapp.com"
 verify_ssl = True
-default_auth_header_bearer = "Api-Optimus-Key"
+default_auth_header_bearer = "Api-Transfa-Key"
 
 
 # API Resources
